import numpy as np
import matplotlib.pyplot as plt
from matplotlib import cm

plt.rc('text', usetex=True)
plt.rc('font', family='serif')

# ---------- Load data from a previous calculation

loadname1 = 'SGS_symmetric_beta_C_1e0_beta_L_1e0_gamma_0' # fig_1a
loadname2 = 'symmetric_beta_C_1e0_beta_L_1e0_gamma_0' # fig_1b

savename1 = 'zero_noise_eg_SGS'
savename2 = 'zero_noise_eg_sinusoidal'
data1 = np.loadtxt(loadname1 + '.dat', delimiter=',')
data2 = np.loadtxt(loadname2 + '.dat', delimiter=',')

v1_array = data1[1:,1:]
v2_array = data2[1:,1:]
p1_array = np.zeros(np.shape(v1_array))
i1_array = np.zeros(np.shape(v1_array))
p2_array = np.zeros(np.shape(v2_array))
i2_array = np.zeros(np.shape(v2_array))

for i in range(np.shape(v1_array)[1]):
    p1_array[:,i] = data1[1:,0]
    
for i in range(np.shape(v1_array)[0]):
    i1_array[i,:] = data1[0,1:]

for i in range(np.shape(v2_array)[1]):
    p2_array[:,i] = data2[1:,0]
    
for i in range(np.shape(v2_array)[0]):
    i2_array[i,:] = data2[0,1:]
    
    
# ---------- 2D plot of SGS data
    
fig, ax = plt.subplots(figsize=(3.5, 3.5))
vmax = 1.45
vmin = -1.45

ax.tick_params(labelsize=11)

cax = ax.pcolormesh(p1_array, i1_array, v1_array, cmap=cm.bwr, vmin=vmin, vmax=vmax, shading='auto', linewidth=0, rasterized=True)
ax.axis([-1, 1, -3, 3])

cbar = fig.colorbar(cax)
cbar.set_label(r'$\left<v\right>$', size=11)
cbar.ax.tick_params(labelsize=11)

ax.set_xlabel(r'$\phi_a$', size=11)
ax.set_ylabel(r'$i$', size=11)

plt.tight_layout()

plt.grid(True)
plt.savefig(savename1 + '.pdf')


# ---------- 2D plot of sinusoidal data
    
fig, ax = plt.subplots(figsize=(3.5, 3.5))
vmax = 1.45
vmin = -1.45

ax.tick_params(labelsize=11)

cax = ax.pcolormesh(p2_array, i2_array, v2_array, cmap=cm.bwr, vmin=vmin, vmax=vmax, shading='auto', linewidth=0, rasterized=True)
ax.axis([-1, 1, -3, 3])

cbar = fig.colorbar(cax)
cbar.set_label(r'$\left<v\right>$', size=11)
cbar.ax.tick_params(labelsize=11)

ax.set_xlabel(r'$\phi_a$', size=11)
ax.set_ylabel(r'$i$', size=11)

plt.tight_layout()

plt.grid(True)
plt.savefig(savename2 + '.pdf')


# ---------- Example line plots of v vs. phi
    
fig, ax = plt.subplots(figsize=(4.5, 2.5))

ax.tick_params(labelsize=11)

idx = 25
print('e.g. line scans taken at i = {:.2f}'.format(i1_array[0,idx]))

ax.plot(p2_array[:,idx], v2_array[:,idx], label=r'$\sin(\delta)$')
ax.plot(p1_array[:,idx], v1_array[:,idx], '--', label='sawtooth')
ax.axis([-1, 1, -0.04, 0.85])

ax.set_xlabel(r'$\phi_a$', size=11)
ax.set_ylabel(r'$\left<v\right>$', size=11)
plt.legend(fontsize=11, loc=2)

plt.tight_layout()

plt.grid(True)
plt.savefig('zero_noise_eg_v_phi.pdf')

