import numpy as np
import matplotlib.pyplot as plt

plt.rc('text', usetex=True)
plt.rc('font', family='serif')

# ---------- Load data from a previous calculation

data_1 = np.loadtxt('symmetric_Ic_vs_beta_L_beta_C_1e-1_gamma_0.dat', delimiter=',')
data_2 = np.loadtxt('short_symmetric_Ic_vs_beta_L_tn_9706e-4_beta_C_10e-2_epsilon_0e+0_gamma_0e+0_int_2e+3-forplotting.dat', delimiter=',')
data_3 = np.loadtxt('SGS_symmetric_Ic_vs_beta_L_beta_C_1e-1_gamma_0.dat', delimiter=',')

beta_Ls_1 = data_1[:,0]
beta_Ls_2 = data_2[:,0]
beta_Ls_3 = data_3[:,0]

dIc_1 = data_1[:,3]
dIc_2 = data_2[:,3]
dIc_3 = data_3[:,3]

# ---------- Plot modulation depth vs. beta_L

fig, ax = plt.subplots(figsize=(4.75, 2.75))

ax.tick_params(labelsize=11)

ax.semilogx(beta_Ls_1, dIc_1,'C0-', label=r'$\sin(\delta)$')
ax.semilogx(beta_Ls_2, dIc_2, 'C2:', label=r'skew $=0.5$')
ax.semilogx(beta_Ls_3, dIc_3, 'C1--', label=r'sawtooth')

ax.set_xlabel(r'$\beta_L$', size=11)
ax.set_ylabel(r'$\Delta i_\mathrm{s}/\mathrm{max}(i_\mathrm{s})$', size=11)

plt.legend(fontsize=11)
plt.grid(True)
plt.tight_layout()
plt.savefig('delta_Ic.pdf')

