import numpy as np
import matplotlib.pyplot as plt

plt.rc('text', usetex=True)
plt.rc('font', family='serif')

# ---------- Load data from previous calculations

data_1 = np.loadtxt('symmetric_Sensitivity_vs_beta_L_beta_C_1e-1_gamma_1e-2_int_4e4-Sphi.dat', delimiter=',')
data_2 = np.loadtxt('short_symmetric_Sensitivity_vs_beta_L_tn_9706e-4_beta_C_10e-2_epsilon_0e+0_gamma_10e-3_int_4e+4-Sphi.dat', delimiter=',')
data_3 = np.loadtxt('SGS_symmetric_Sensitivity_vs_beta_L_beta_C_1e-1_gamma_1e-2_int_4e4-Sphi.dat', delimiter=',')

gamma = 1e-2

# -------- Extract data

beta_Ls_1 = data_1[:,0]
SPhis_1 = data_1[:,1]

beta_Ls_2 = data_2[:,0]
SPhis_2 = data_2[:,1]

beta_Ls_3 = data_3[:,0]
SPhis_3 = data_3[:,1]

# --------  Plot sensitivity as a function of beta_L

fig, ax = plt.subplots(figsize=(4, 3))

ax.tick_params(labelsize=11)

ax.loglog(beta_Ls_1, SPhis_1, 'C0o', markersize=4, label=r'$\sin(\delta)$')
ax.loglog(beta_Ls_2, SPhis_2, 'C2^', markersize=4, label=r'skew $=0.5$')
ax.loglog(beta_Ls_3, SPhis_3, 'C1s', markersize=4, label=r'sawtooth')

ax.axis([7e-3, 2.6e2, 3e-3, 1.4e1])
ax.set_xlabel(r'$\beta_L$', size=11)
ax.set_ylabel(r'$s_\phi$', size=11)

plt.legend(fontsize=11)
plt.grid(True)
plt.tight_layout()
plt.savefig('Sensitivity_vs_beta_L.pdf')
