import numpy as np
import matplotlib.pyplot as plt

plt.rc('text', usetex=True)
plt.rc('font', family='serif')

# ---------- Load data from previous calculations

data_1 = np.loadtxt('symmetric_Sensitivity_vs_gamma_beta_C_1e-1_beta_L_1e0_int_4e4-Sphi.dat', delimiter=',')
data_2 = np.loadtxt('short_symmetric_Sensitivity_vs_gamma_tn_9706e-4_beta_C_10e-2_beta_L_10e-1_epsilon_0e+0_int_4e+4-Sphi.dat', delimiter=',')
data_3 = np.loadtxt('SGS_symmetric_Sensitivity_vs_gamma_beta_C_1e-1_beta_L_1e0_int_4e4-Sphi.dat', delimiter=',')

# -------- Extract data

gammas_1 = data_1[:,0]
SPhis_1 = data_1[:,1]

gammas_2 = data_2[:,0]
SPhis_2 = data_2[:,1]

gammas_3 = data_3[:,0]
SPhis_3 = data_3[:,1]

# --------  Plot sensitivity as a function of gamma (noise power)

fig, ax = plt.subplots(figsize=(4, 3))

ax.tick_params(labelsize=11)

ax.loglog(gammas_1, SPhis_1, 'C0o', markersize=4, label=r'$\sin(\delta)$')
ax.loglog(gammas_2, SPhis_2, 'C2^', markersize=4, label=r'skew $=0.5$')
ax.loglog(gammas_3, SPhis_3, 'C1s', markersize=4, label=r'sawtooth')

ax.set_xlabel(r'$\Gamma$', size=11)
ax.set_ylabel(r'$s_\phi$', size=11)

plt.legend(fontsize=11)
plt.grid(True)
plt.tight_layout()
plt.savefig('Sensitivity_vs_gamma.pdf')

